@@ -3,7 +3,7 @@
 
 ##############################################################
 ##   smscon-editor  -  Configuration UI for the SMSCON      ##
-# $Id: smsconEditorMain.py 108 2011-12-28 18:46:50Z saturn $
+# $Id: smsconEditorMain.py 130 2011-12-29 22:26:21Z saturn $
 ##############################################################
 # Copyright (c) 2010-2011 Christos Zamantzas
 # Licenced under GPLv2
@@ -22,7 +22,7 @@
 ## GNU General Public License for more details.
 ##
 
-Version = '0.9.8-1'
+Version = '0.9.9-1'
 
 import os
 import sys
@@ -353,11 +353,15 @@ class smsconEditorMainWindow(QtGui.QMainWindow):
 
     def closeEvent(self, event):
        """Cleanup on close."""
+
        event.accept()
-       if self.isSmsconTestActive:
-          message = 'Test mode was active.\nSwitching to normal operation...'
-          showQuickMessage(message)
-       self.doRestart();
+
+       DAEMONSTATE = os.popen('sudo smscon -status').read().strip('\n') 
+       if DAEMONSTATE.endswith('running'):
+          if self.isSmsconTestActive:
+             message = 'Test mode was active.\nSwitching to normal operation...'
+             showQuickMessage(message)
+          self.doRestart();
 
     def SetSystemValues(self):
        '''Set GUI values from the current operation'''
@@ -469,7 +473,8 @@ class smsconEditorInit(QtGui.QMainWindow):     ## Initialise SMSCON
                     'This editor will now quit...\n\n' \
                     'You will need to open it again and edit your new configuration.'
         showMessage(message)
-        sys.exit()
+        self.close()
+        sys.exit(0)
         
     def doReset(self):
 
@@ -842,14 +847,15 @@ class smsconEditorTest(QtGui.QMainWindow):     ## Testing of main functions for
        self.show()       
 
        ##Connect the GUI Buttons with the Tests 
-       QtCore.QObject.connect(self.ui.btnTestMail1,   QtCore.SIGNAL('clicked()'), self.doSendTestMail1)
-       QtCore.QObject.connect(self.ui.btnTestMail2,   QtCore.SIGNAL('clicked()'), self.doSendTestMail2)
-       QtCore.QObject.connect(self.ui.btnTestGPS1,    QtCore.SIGNAL('clicked()'), self.doSendTestGPS1)
-       QtCore.QObject.connect(self.ui.btnTestGPS2,    QtCore.SIGNAL('clicked()'), self.doSendTestGPS2)
-       QtCore.QObject.connect(self.ui.btnTestCall,    QtCore.SIGNAL('clicked()'), self.doSendTestCall)
-       QtCore.QObject.connect(self.ui.btnTestSMS,     QtCore.SIGNAL('clicked()'), self.doSendTestSMS)
-       QtCore.QObject.connect(self.ui.btnTestSSH,     QtCore.SIGNAL('clicked()'), self.doSendTestSSH)
-       QtCore.QObject.connect(self.ui.btnTestScript,  QtCore.SIGNAL('clicked()'), self.doSendTestScript)  
+       QtCore.QObject.connect(self.ui.btnTestMail1,      QtCore.SIGNAL('clicked()'), self.doSendTestMail1)
+       QtCore.QObject.connect(self.ui.btnTestMail2,      QtCore.SIGNAL('clicked()'), self.doSendTestMail2)
+       QtCore.QObject.connect(self.ui.btnTestGPS1,       QtCore.SIGNAL('clicked()'), self.doSendTestGPS1)
+       QtCore.QObject.connect(self.ui.btnTestGPS2,       QtCore.SIGNAL('clicked()'), self.doSendTestGPS2)
+       QtCore.QObject.connect(self.ui.btnTestCall,       QtCore.SIGNAL('clicked()'), self.doSendTestCall)
+       QtCore.QObject.connect(self.ui.btnTestSMS,        QtCore.SIGNAL('clicked()'), self.doSendTestSMS)
+       QtCore.QObject.connect(self.ui.btnTestSSHstart,   QtCore.SIGNAL('clicked()'), self.doSendTestSSHstart)
+       QtCore.QObject.connect(self.ui.btnTestSSHend,     QtCore.SIGNAL('clicked()'), self.doSendTestSSHend)
+       QtCore.QObject.connect(self.ui.btnTestScript,     QtCore.SIGNAL('clicked()'), self.doSendTestScript)  
           
     def smsconTest(self, testArgs, testTopic):
        '''Initiate an SMSCON test using the given command line testArgs and given testTopic string'''
@@ -880,9 +886,12 @@ class smsconEditorTest(QtGui.QMainWindow):     ## Testing of main functions for
     def doSendTestSMS(self):
        self.smsconTest('-test sms', 'An SMS to the master number should have been send.')
       
-    def doSendTestSSH(self):
+    def doSendTestSSHstart(self):
        self.smsconTest('-test ssh', 'The reverse SSH connection should be possible now.')
       
+    def doSendTestSSHend(self):
+       self.smsconTest('-test ssh-off', 'The reverse SSH connection should be closed now.')
+
     def doSendTestScript(self):
        self.smsconTest('-test script', 'The script execution has been invoked.')
       
